@@ -4,7 +4,11 @@ import time
 import random
 from itertools import imap, chain
 
-from utils import encode, decode, check_columns
+try:
+    from _speedups import encode, decode
+except ImportError:
+    from utils import encode, decode
+from utils import check_columns
 from exceptions import *
 
 
